.. :changelog:

History
-------

0.1.3 (2017-04-18)
++++++++++++++++++

- Use a Block if the sql file contains a 'ALTER TYPE' instruction
  Add a setting to customize the files to run in a Block.


0.1.2 (2017-04-13)
++++++++++++++++++

- Use a Block if the sql file contains a CONCURRENTLY instruction


0.1.1 (2017-04-11)
++++++++++++++++++

- Add the possibility to configure the current version detector


0.1.0 (2017-03-28)
++++++++++++++++++

- First release on PyPI.
